@@ -81,6 +81,13 @@ class GraphSpace:
 		else:
 			return None
 
+	def get_graph_by_id(self, graph_id):
+		"""Get a graph by id.
+
+		:return: Graph Object if a graph with given id exists otherwise None.
+		"""
+		return self._make_request("GET", '/api/v1/graphs/%s'% graph_id).json()
+
 	def get_public_graphs(self, tags=None, limit=20, offset=0):
 		"""Get public graphs.
 
